@@ -2,7 +2,7 @@ from extras.plugins import PluginTemplateExtension
 from itertools import chain
 import logging
 
-from netbox_storage.models import Drive, Partition, PhysicalVolume, LogicalVolume, VolumeGroup
+from netbox_storage.models import Drive, Partition, PhysicalVolume, LogicalVolume, VolumeGroup, LinuxVolume
 
 
 class LVMModel:
@@ -24,12 +24,12 @@ class RelatedDrives(PluginTemplateExtension):
         obj = self.context.get("object")
 
         # --- Try via Logical Volume
-        lvs = LogicalVolume.objects.all()
+        logicalvolumes = LogicalVolume.objects.all()
         lvm_list = []
         logger = logging.getLogger('netbox.plugins.netbox_storage')
 
         # appending instances to list
-        for lv in lvs:
+        for lv in logicalvolumes:
             logger.warning(f'{lv.vg}')
             lvm_list.append(LVMModel(lv.lv_name, lv.path, lv.fs, lv.size, lv.vg.vg_name))
             physical_volumes = PhysicalVolume.objects.all()
@@ -51,10 +51,14 @@ class RelatedDrives(PluginTemplateExtension):
             #                 partition_list.append(f"{partition.device}-{partition.size}")
             #                 lvm_model.partition_list = partition_list
 
+        linux_volume_list = []
+        linuxvolumes = LinuxVolume.objects.all()
+        linux_volume_list = list(LinuxVolume.objects.all())
+        logger.warning(f'linuxvolumes for {linux_volume_list}')
 
-        drives = Drive.objects.filter(
-            virtual_machine=obj
-        )
+        # drives = Drive.objects.filter(
+        #     virtual_machine=obj
+        # )
         # drive_table = RelatedDriveTable(
         #     data=drives
         # )
@@ -79,14 +83,14 @@ class RelatedDrives(PluginTemplateExtension):
         #        drive=drive
         #    )
 
-        hd_partition_list = []
-        for drive in drives:
-            hd_partition = [drive]
-            partitions = Partition.objects.filter(
-                drive=drive
-            ).values_list()
-            hd_partition.append(partitions)
-            hd_partition_list.append(hd_partition)
+        # hd_partition_list = []
+        # for drive in drives:
+        #     hd_partition = [drive]
+        #     partitions = Partition.objects.filter(
+        #         drive=drive
+        #     ).values_list()
+        #     hd_partition.append(partitions)
+        #     hd_partition_list.append(hd_partition)
 
         #physical_volumes = PhysicalVolume.objects.filter(
         #    partition__in=partitions
@@ -101,7 +105,6 @@ class RelatedDrives(PluginTemplateExtension):
         # result_list = list(chain(drives, partitions, volume_group_list, logical_volumes))
         logger = logging.getLogger('netbox.plugins.netbox_storage')
         # logger.warning(f'{result_list}')
-        logger.warning(f'{hd_partition_list}')
 
 
         platform = obj.platform
@@ -122,9 +125,10 @@ class RelatedDrives(PluginTemplateExtension):
                     "netbox_storage/inc/linuxvolume_box.html",
                     extra_context={
                         "lvm_list": lvm_list,
+                        "linux_volume_list": linux_volume_list,
                         #"physical_volumes": physical_volumes,
                         #"logical_volumes": logical_volumes,
-                        "hd_partition_list": hd_partition_list
+                        #"hd_partition_list": hd_partition_list
                     },
                 )
         else:
